@@ -8,14 +8,19 @@ from typing import List, Optional
 
 from jinja2 import Template
 
+from ts_cli.commands.init_cmd.init_artifact_config import (
+    InitArtifactConfig,
+    InitTemplateConfig,
+)
+from ts_cli.commands.init_cmd.kinds import KIND_TEMPLATES, KINDS, TEMPLATES
 from ts_cli.commands.utils import any_namespace_type, platform_version_type
 from ts_cli.config.cli_config import CliConfig
-from ts_cli.config.init_artifact_config import InitArtifactConfig, InitTemplateConfig
 from ts_cli.config.util import to_version
-from ts_cli.util.emit import emit_critical, emit_error, emit_warning
+from ts_cli.errors.critical_error import CriticalError
+from ts_cli.util.emit import emit_error, emit_warning
 from ts_cli.util.files import copy, delete, get_conflicts
 
-MAX_KNOWN_PLATFORM_VERSION = 4.2
+MAX_KNOWN_PLATFORM_VERSION = 4.3
 
 
 def add_init_parser(subparsers):
@@ -32,15 +37,17 @@ def add_init_parser(subparsers):
             description=textwrap.dedent(
                 f"""
                 Create a new artifact for the Tetra Data Platform. For example:
-                
+
                     ts-cli init protocol .
-                
-                where "." is the path to the new artifact source.
-                The source code positional argument defaults to the current working directory.
-                
-                The template configuration field is required.
-                
-                Each template uses 1 to 3 artifact configurations,
+
+                Syntax:
+                    ts-cli init <kind> <target>
+
+                The target directory defaults to the current working directory.
+
+                The kind configuration field is required.
+
+                Each template uses up to 3 artifact configurations,
                     protocol, task-script, or ids
                   consisting of the following fields:
                     namespace, slug, version
@@ -55,19 +62,19 @@ def add_init_parser(subparsers):
                   a configured org (see below)
                 If no configuration can be found, it will either be omitted, or filled in
                   with default values from [common/example:v1.0.0@main] if it is required.
-                
+
                 The init command will sequentially check each of the following locations
                   for an org
                     1. In the process's environment variables, at TS_ORG
                     2. The yaml or json formatted file at  "~/.config/tetrascience/config"
-                
+
                 The init command has support for multiple Tetra Data Platform versions.
                   The init command will sequentially check each of the following locations
                   for a configured platform version
                     1. The `--platform-version` command line argument
                     2. In the process's environment variables, at TS_PLATFORM_VERSION
                     3. The yaml or json formatted file at "~/.config/tetrascience/config"
-                  If no platform versio is found, the current TDP version
+                  If no platform version is found, the current TDP version
                     v{MAX_KNOWN_PLATFORM_VERSION} is assumed.
                 """
             ),
@@ -160,11 +167,17 @@ def init_cmd_args(parser: ArgumentParser):
     )
 
     parser.add_argument(
-        "template",
+        "--template",
         type=str,
-        choices=["ids", "protocol", "task-script", "tetraflow"],  # TODO "all-in-one"
+        choices=TEMPLATES,
+        help="Template to use",
+    )
+    parser.add_argument(
+        "kind",
+        type=str,
+        choices=KINDS,
         nargs="?",
-        help="artifact template to use",
+        help="Artifact kind to use",
     )
     parser.add_argument(
         "target",
@@ -187,7 +200,7 @@ def get_pretty_name(artifact_type: str) -> str:
     elif artifact_type == "tetraflow":
         return "Tetraflow"
     else:
-        raise NotImplemented(f"Unrecognized type: {artifact_type}")
+        raise CriticalError(f"Unrecognized type: {artifact_type}")
 
 
 def init_artifact_config(
@@ -242,19 +255,19 @@ def tetraflow_template_config(args) -> List[InitArtifactConfig]:
     return [tetraflow]
 
 
-def create_template_config_list(args, template: str) -> List[InitArtifactConfig]:
-    if template == "task-script":
+def create_template_config_list(args, kind: str) -> List[InitArtifactConfig]:
+    if kind == "task-script":
         configs = task_script_template_config(args)
-    elif template == "protocol":
+    elif kind == "protocol":
         configs = protocol_template_config(args)
-    elif template == "ids":
+    elif kind == "ids":
         configs = ids_template_config(args)
-    elif template == "all-in-one":
+    elif kind == "all-in-one":
         configs = all_template_config(args)
-    elif template == "tetraflow":
+    elif kind == "tetraflow":
         configs = tetraflow_template_config(args)
     else:
-        raise Exception(f"Invalid template type provided: {template}")
+        raise CriticalError(f"Invalid kind provided: {kind}")
     for config in configs:
         config.print()
     return configs
@@ -268,15 +281,15 @@ def create_environment(configs: List[InitArtifactConfig]) -> dict:
     return environment
 
 
-def list_template_versions_in_dir(template_type_dir: Path) -> List[float]:
-    platform_versions = [float(entry) for entry in os.listdir(template_type_dir)]
+def list_template_versions_in_dir(template_path_dir: Path) -> List[float]:
+    platform_versions = [float(entry) for entry in os.listdir(template_path_dir)]
     platform_versions.sort()
     platform_versions.reverse()
     return platform_versions
 
 
-def get_template_dir(template_type: str) -> Path:
-    return Path(__file__).parent.joinpath("templates", template_type)
+def get_template_dir(kind: str) -> Path:
+    return Path(__file__).parent.joinpath("templates", kind)
 
 
 def select_template_version(
@@ -293,18 +306,45 @@ def select_template_version(
     )
 
 
-def pick_template(template_type: str, platform_version: str) -> Path:
-    template_type_dir = get_template_dir(template_type)
-    platform_versions = list_template_versions_in_dir(template_type_dir)
+def pick_template(
+    *,
+    kind: str,
+    platform_version: str,
+    template: str,
+) -> Path:
+    kind_dir = get_template_dir(kind)
+
+    if kind not in KIND_TEMPLATES:
+        raise CriticalError(f"Unknown kind '{kind}'")
+
+    if template not in KIND_TEMPLATES[kind]:
+        raise CriticalError(
+            f"Invalid template '{template}' for kind '{kind}'. "
+            f"Must be one of {KIND_TEMPLATES[kind]}"
+        )
+
+    template_dir = kind_dir.joinpath(template)
+    if not template_dir.exists():
+        raise CriticalError(
+            f"Template directory '{template}' does not exist for kind '{kind}'"
+        )
+
+    platform_versions = list_template_versions_in_dir(template_dir)
     numeric_platform_version = float(platform_version.replace("v", ""))
     selected_version = select_template_version(
         platform_versions, numeric_platform_version
     )
     if selected_version is None:
-        raise emit_critical(
+        raise CriticalError(
             f"Aborting because version {platform_version} is not supported"
         )
-    return template_type_dir.joinpath(str(selected_version))
+
+    template_path = template_dir.joinpath(str(selected_version))
+
+    if not template_path.exists():
+        raise CriticalError(f"Template directory does not exist: {template_path}")
+
+    return template_path
 
 
 def resolve_conflicts(
@@ -321,19 +361,24 @@ def resolve_conflicts(
         conflict_count = len(conflicting_entries)
         noun = "file" if conflict_count == 1 else "files"
         verb = "conflicts" if conflict_count == 1 else "conflict"
-        raise emit_critical(
+        raise CriticalError(
             f"Aborting because {conflict_count} {noun} in the target directory {verb} with the template"
         )
     delete(*conflicting_entries)
 
 
 def init(args):
-    template = InitTemplateConfig(args, interactive=args.interactive).template
-    environment = create_environment(create_template_config_list(args, template))
+    init_template_config = InitTemplateConfig(args, interactive=args.interactive)
+    kind = init_template_config.kind
+    template = init_template_config.template
+
+    environment = create_environment(create_template_config_list(args, kind))
     platform_version = (
         CliConfig(args).get("platform_version") or f"v{MAX_KNOWN_PLATFORM_VERSION}"
     )
-    template_directory = pick_template(template, platform_version)
+    template_directory = pick_template(
+        kind=kind, platform_version=platform_version, template=template
+    )
 
     resolve_conflicts(
         template_directory=template_directory,
