@@ -14,7 +14,8 @@ from ts_cli.config.api_config import ApiConfig
 from ts_cli.config.publish_artifact_config import PublishArtifactConfig
 from ts_cli.config.util import to_version
 
-from ...util.emit import emit_critical, emit_error, emit_info
+from ...errors.critical_error import CriticalError
+from ...util.emit import emit_error, emit_info
 from .archive_utils import compress_directory, copy_included_files_to
 from .common_artifact_utils import update_manifest
 from .errors import ArtifactBuildError
@@ -320,4 +321,4 @@ def publish(args):
         ):
             emit_error("No build ID found in platform response")
     else:
-        emit_critical("Skipping artifact upload because 'dry-run' flag was set")
+        raise CriticalError("Skipping artifact upload because 'dry-run' flag was set")
