@@ -7,6 +7,9 @@ from typing import Iterable, Union
 from ts_cli.util.files import copy
 
 
+UNIX_PERMISSION_MASK = 0xFFFF
+
+
 def abs_path_relative_to(relative_path, relative_to):
     """
     Join the two paths, and then provide the absolute path
@@ -115,6 +118,44 @@ def copy_included_files_to(
         copy(src=Path(src_dir, relative_path), dst=Path(dst_dir, relative_path))
 
 
+def write_file_to_archive(
+    zip_archive: zipfile.ZipFile,
+    local_path: Union[str, Path],
+    relative_path: Union[str, Path],
+):
+    st = os.stat(local_path)
+    mode = st.st_mode
+    # For files: ensure all have r--, set x if set for owner
+    new_mode = mode
+    # Set read to all
+    new_mode |= 0o444
+    # Set execute for all if owner had it
+    if mode & 0o100:
+        new_mode |= 0o111
+    zi = zipfile.ZipInfo(relative_path)
+    zi.external_attr = (
+        new_mode & UNIX_PERMISSION_MASK
+    ) << 16  # upper 16 bits are unix permissions
+    with open(local_path, "rb") as f:
+        zip_archive.writestr(zi, f.read())
+
+
+def write_folder_to_archive(
+    zip_archive: zipfile.ZipFile,
+    local_path: Union[str, Path],
+    relative_path: Union[str, Path],
+):
+    st = os.stat(local_path)
+    mode = st.st_mode
+    # For dirs: ensure all have r-x
+    new_mode = mode | 0o555  # add r-x for all
+    zi = zipfile.ZipInfo(relative_path + "/")
+    zi.external_attr = (
+        new_mode & UNIX_PERMISSION_MASK
+    ) << 16  # upper 16 bits are unix permissions
+    zip_archive.writestr(zi, b"")
+
+
 def add_directory_to_archive(
     zip_archive: zipfile.ZipFile,
     path: Union[str, Path],
@@ -125,11 +166,15 @@ def add_directory_to_archive(
     :param path:
     :return:
     """
-    for root, _folders, files in os.walk(path, topdown=True):
+    for root, folders, files in os.walk(path, topdown=True):
         for file in files:
             local_path = os.path.join(root, file)
             relative_path = os.path.relpath(local_path, os.path.join(path))
-            zip_archive.write(local_path, relative_path)
+            write_file_to_archive(zip_archive, local_path, relative_path)
+        for folder in folders:
+            local_path = os.path.join(root, folder)
+            relative_path = os.path.relpath(local_path, os.path.join(path))
+            write_folder_to_archive(zip_archive, local_path, relative_path)
     return zip_archive
 
 
