@@ -3,13 +3,16 @@ from pathlib import Path
 
 from ids_validator.ids_validator import validate_ids_using_tdp_artifact
 from ids_validator.tdp_api import APIConfig as IDSValidatorAPIConfig
+from ts_protocol_virtual_machine import compiler
+from ts_protocol_virtual_machine.messages import Message
 
 from ts_cli.config.api_config import ApiConfig
 from ts_cli.config.util import (
     load_from_json_file_if_present,
     load_from_yaml_file_if_present,
 )
-from ts_cli.util.emit import emit_critical, emit_error, emit_warning
+from ts_cli.errors.critical_error import CriticalError
+from ts_cli.util.emit import emit_error, emit_warning
 
 from .validator import Validator
 
@@ -50,7 +53,7 @@ def get_source_validator(
         return ProtocolValidator(path=path, exiting=exiting)
     if validator_type == "tetraflow":
         return TetraflowValidator(path=path, exiting=exiting)
-    raise emit_critical(f"Invalid type provided: {validator_type}")
+    raise CriticalError(f"Invalid type provided: {validator_type}")
 
 
 class SourceValidator(Validator):
@@ -71,7 +74,7 @@ class ConnectorValidator(SourceValidator):
     def validate(self):
         package_content = os.listdir(self._path)
         if "image.tar" not in package_content:
-            raise emit_critical(
+            raise CriticalError(
                 "Connector package must contain 'image.tar' containing the Connector's Docker image."
             )
 
@@ -106,7 +109,7 @@ class IdsValidator(SourceValidator):
                 "of the command for details."
             )
             if self._exiting:
-                emit_critical("Exiting")
+                raise CriticalError("Exiting")
 
 
 class TaskScriptValidator(SourceValidator):
@@ -118,7 +121,7 @@ class TaskScriptValidator(SourceValidator):
         # DE-3436: task-script folder must contain requirements.txt
         package_content = os.listdir(self._path)
         if "requirements.txt" not in package_content:
-            raise emit_critical("Task-Script package must contain 'requirements.txt'.")
+            raise CriticalError("Task-Script package must contain 'requirements.txt'.")
 
 
 class ProtocolValidator(SourceValidator):
@@ -126,25 +129,42 @@ class ProtocolValidator(SourceValidator):
     Validates a Protocol artifact's source files
     """
 
-    def validate(self):
-        manifest_path = Path(self._path, "manifest.json")
-        if manifest_path.exists():
-            manifest = load_from_json_file_if_present(manifest_path)
-            for filename in ["protocol.yml", "protocol.yaml"]:
-                path = Path(self._path, filename)
-                if path.exists():
-                    ProtocolValidator._emit_manifest_warnings(
-                        protocol=load_from_yaml_file_if_present(path),
-                        manifest=manifest,
-                        filename=filename,
-                    )
-            path = Path(self._path, "protocol.json")
-            if path.exists():
-                ProtocolValidator._emit_manifest_warnings(
-                    protocol=load_from_json_file_if_present(path),
-                    manifest=manifest,
-                    filename="protocol.json",
-                )
+    @staticmethod
+    def format_message(filename: str, message: Message):
+        path = f"[{message.source_path}] " if message.source_path else ""
+        expression = f"$( {message.expression} ) " if message.expression else ""
+        return f"{filename} >> {path}{expression}{message.content}"
+
+    @staticmethod
+    def load_protocol(path: Path):
+        if path.suffix == ".json":
+            return load_from_json_file_if_present(path)
+        return load_from_yaml_file_if_present(path)
+
+    @staticmethod
+    def validate_v3_protocol(filename: str, protocol: dict):
+        def emit_warnings(_, warnings):
+            for warning in warnings:
+                emit_warning(ProtocolValidator.format_message(filename, warning))
+
+        def emit_warnings_and_errors_and_exit(errors, warnings):
+            emit_warnings(None, warnings)
+            for error in errors:
+                emit_error(ProtocolValidator.format_message(filename, error))
+            raise CriticalError("Exiting")
+
+        compiler.protocol_lang.to.pvm(protocol).match(
+            emit_warnings,
+            emit_warnings_and_errors_and_exit,
+        )
+
+    @staticmethod
+    def validate_protocol(filename: str, protocol: dict, manifest: dict):
+        if protocol.get("protocolSchema", None) == "v3":
+            ProtocolValidator.validate_v3_protocol(filename, protocol)
+        ProtocolValidator._emit_manifest_warnings(
+            protocol=protocol, manifest=manifest, filename=filename
+        )
 
     @staticmethod
     def _emit_manifest_warnings(*, protocol: dict, manifest: dict, filename: str):
@@ -158,6 +178,15 @@ class ProtocolValidator(SourceValidator):
                         + f"manifest.json value '{manifest_value}'"
                     )
 
+    def validate(self):
+        manifest = load_from_json_file_if_present(Path(self._path, "manifest.json"))
+        for filename in ["protocol.yml", "protocol.yaml", "protocol.json"]:
+            path = Path(self._path, filename)
+            if path.exists():
+                ProtocolValidator.validate_protocol(
+                    filename, ProtocolValidator.load_protocol(path), manifest
+                )
+
 
 class TetraflowValidator(SourceValidator):
     """
