@@ -1,4 +1,5 @@
-from ts_cli.util.emit import emit_critical, emit_error
+from ts_cli.errors.critical_error import CriticalError
+from ts_cli.util.emit import emit_error
 
 from .validator import Validator
 
@@ -49,6 +50,6 @@ class UploadValidator(Validator):
             )
 
             if self._exiting:
-                emit_critical("Exiting")
+                raise CriticalError("Exiting")
             return False
         return True
