@@ -12,7 +12,8 @@ from ts_cli.commands.utils import existing_folder_type, private_namespace_type
 from ts_cli.config.api_config import ApiConfig
 from ts_cli.config.update_artifact_config import UpdateArtifactConfig
 from ts_cli.config.util import to_version
-from ts_cli.util.emit import emit_critical, emit_info, emit_warning
+from ts_cli.errors.critical_error import CriticalError
+from ts_cli.util.emit import emit_info, emit_warning
 
 
 def add_unpublish_parser(subparsers):
@@ -30,12 +31,12 @@ def add_unpublish_parser(subparsers):
             description=textwrap.dedent(
                 """
             Unpublish an artifact from the Tetra Data Platform. For example:
-            
+
                 ts-cli unpublish .
-            
+
             where "." is the path to the artifact souce code.
             The source code positional argument defaults to the current working directory.
-            
+
             The following artifact configuration fields are required:
                 type, namespace, slug, version
             The unpublish command will sequentially check each of the following locations
@@ -51,7 +52,7 @@ def add_unpublish_parser(subparsers):
             For the version field, the unpublish command will additionally look for a
               pyproject.toml file in the root of the artifact directory
             Use --interactive to be walked through setting up each of the fields
-            
+
             The following TDP API configuration fields are required:
                 org, api_url, auth_token, ignore_ssl
             The unpublish command will sequentially check each of the following locations
@@ -165,7 +166,7 @@ def confirm(config: UpdateArtifactConfig):
         [inquirer.Text("confirmation", message="Confirmation", validate=is_confirmed)]
     )
     if values is None:
-        raise emit_critical("Unpublish interrupted")
+        raise CriticalError("Unpublish interrupted")
 
 
 def unpublish(args):
@@ -188,4 +189,6 @@ def unpublish(args):
         response = ts_api.delete_artifact(artifact_config)
         print(json.dumps(response, indent="\t", sort_keys=True), flush=True)
     else:
-        emit_critical("Skipping artifact unpublish because 'dry-run' flag was set")
+        raise CriticalError(
+            "Skipping artifact unpublish because 'dry-run' flag was set"
+        )
