@@ -3,7 +3,8 @@ import textwrap
 from ts_cli.api import TsApi
 from ts_cli.commands.publish_cmd.validation.validator import Validator
 from ts_cli.config.update_artifact_config import UpdateArtifactConfig
-from ts_cli.util.emit import emit_critical, emit_warning
+from ts_cli.errors.critical_error import CriticalError
+from ts_cli.util.emit import emit_warning
 
 
 def validate_unused(*, ts_api: TsApi, artifact_config: UpdateArtifactConfig) -> None:
@@ -29,7 +30,7 @@ def get_usage_validator(
         return AlwaysPassing(
             ts_api=ts_api, artifact_config=artifact_config, exiting=False
         )
-    raise emit_critical(f"Invalid type provided: {artifact_config.type}")
+    raise CriticalError(f"Invalid type provided: {artifact_config.type}")
 
 
 class UsageValidator(Validator):
