@@ -1,9 +1,11 @@
+from typing import Optional
+
 import inquirer
 
 from ts_cli.config.cli_config import CliConfig
 from ts_cli.config.config import Config
 from ts_cli.config.provider import Provider
-from ts_cli.util.emit import emit_critical
+from ts_cli.errors.critical_error import CriticalError
 
 
 class InteractiveConfig(Config):
@@ -22,20 +24,33 @@ class InteractiveConfig(Config):
         values: dict = {key: provider.get(key) or None for key in keys}
         if not self._interactive:
             return values
+        return self._interactive_resolve_values_and_confirm(values, skip_confirmation)
+
+    def _interactive_resolve_values(
+        self, values: dict, confirmation: Optional[inquirer.Confirm] = None
+    ) -> Optional[dict]:
+        inquiry = self._get_inquiry(values)
+        if confirmation:
+            inquiry.append(confirmation)
+        return inquirer.prompt(inquiry)
+
+    def _interactive_resolve_values_and_confirm(
+        self, values: dict, skip_confirmation: bool = False
+    ) -> dict:
+        if skip_confirmation:
+            confirmation = None
+        else:
+            confirmation = inquirer.Confirm(
+                "confirmed",
+                message=self._get_correct_message,
+                default=False,
+            )
+
         values["confirmed"] = False
         while values.get("confirmed", False) is not True:
-            inquiry = self._get_inquiry(values)
-            if not skip_confirmation:
-                inquiry.append(
-                    inquirer.Confirm(
-                        "confirmed",
-                        message=self._get_correct_message,
-                        default=False,
-                    )
-                )
-            values = inquirer.prompt(inquiry)
+            values = self._interactive_resolve_values(values, confirmation)
             if values is None:
-                raise emit_critical("Configuration interrupted")
+                raise CriticalError("Configuration interrupted")
             if skip_confirmation:
                 values["confirmed"] = True
         return self._parse(values)
