@@ -1,4 +1,5 @@
 import os
+import re
 import time
 from pathlib import Path
 from xml.etree import ElementTree
@@ -8,13 +9,23 @@ import requests
 from ts_cli.util.emit import emit_warning
 
 
+def is_release_version(version: str) -> bool:
+    return bool(re.search(r"^\d+\.\d+\.\d+$", version))
+
+
 def get_latest_version():
     try:
-        r = requests.get(
+        response = requests.get(
             "https://pypi.org/rss/project/tetrascience-cli/releases.xml", timeout=5
         )
-        root = ElementTree.fromstring(r.content)
-        return root.findall("channel/item/title")[0].text
+        root = ElementTree.fromstring(response.content)
+        versions = [title.text for title in root.findall("channel/item/title")]
+        releases = [
+            version.strip()
+            for version in versions
+            if version and is_release_version(version)
+        ]
+        return releases[0]
     except:
         return "0.0.0"
 
@@ -39,7 +50,7 @@ def check_update_required(current_version) -> None:
             current_version, latest_version
         ):
             emit_warning(
-                f"\nPlease upgrade ts-cli (local: {current_version}, latest: {latest_version})"
+                f"Please upgrade ts-cli (local: {current_version}, latest: {latest_version})"
             )
             emit_warning("Use: pip install tetrascience-cli --upgrade\n")
 
